@@ -213,22 +213,29 @@ class Slice(np.lib.mixins.NDArrayOperatorsMixin):
             for mesh in remove_tmp:
                 del self._subslices[mesh]
 
-        vals = self._subslices.values()
-        self.extent = Extent(min(vals, key=lambda e: e.extent.x_start).extent.x_start,
-                             max(vals, key=lambda e: e.extent.x_end).extent.x_end,
-                             min(vals, key=lambda e: e.extent.y_start).extent.y_start,
-                             max(vals, key=lambda e: e.extent.y_end).extent.y_end,
-                             min(vals, key=lambda e: e.extent.z_start).extent.z_start,
-                             max(vals, key=lambda e: e.extent.z_end).extent.z_end)
+        subslices = self._subslices.values()
+        orientations = list()
+        # Check if all subslices are 2D. If so, the whole slice is 2D, even though it would have a 3D bounding box
+        for subslice in subslices:
+            if subslice.extent.x_start == subslice.extent.x_end:
+                orientations.append(1)
+            elif subslice.extent.y_start == subslice.extent.y_end:
+                orientations.append(2)
+            elif subslice.extent.z_start == subslice.extent.z_end:
+                orientations.append(3)
+            else:
+                orientations.append(0)
+        self.orientation = 0 if any(o != orientations[0] for o in orientations) else orientations[0]
 
-        if self.extent.x_start == self.extent.x_end:
-            self.orientation = 1
-        elif self.extent.y_start == self.extent.y_end:
-            self.orientation = 2
-        elif self.extent.z_start == self.extent.z_end:
-            self.orientation = 3
-        else:
-            self.orientation = 0
+        x_start, x_end, y_start, y_end, z_start, z_end = min(subslices, key=lambda e: e.extent.x_start).extent.x_start, \
+                                                         max(subslices, key=lambda e: e.extent.x_end).extent.x_end, \
+                                                         min(subslices, key=lambda e: e.extent.y_start).extent.y_start, \
+                                                         max(subslices, key=lambda e: e.extent.y_end).extent.y_end, \
+                                                         min(subslices, key=lambda e: e.extent.z_start).extent.z_start, \
+                                                         max(subslices, key=lambda e: e.extent.z_end).extent.z_end
+        self.extent = Extent(x_start, x_start if self.orientation == 1 else x_end,
+                             y_start, y_start if self.orientation == 2 else y_end,
+                             z_start, z_start if self.orientation == 3 else z_end)
 
         # If lazy loading has been disabled by the user, load the data instantaneously instead
         if not settings.LAZY_LOAD:
@@ -285,7 +292,7 @@ class Slice(np.lib.mixins.NDArrayOperatorsMixin):
     def get_nearest_index(self, dimension: Literal['x', 'y', 'z'], value: float) -> int:
         """Get the nearest mesh coordinate index in a specific dimension.
         """
-        coords = self.coordinates[dimension]
+        coords = self.get_coordinates()[dimension]
         idx = np.searchsorted(coords, value, side="left")
         if idx > 0 and (idx == coords.size or np.math.fabs(value - coords[idx - 1]) < np.math.fabs(
                 value - coords[idx])):
@@ -299,18 +306,23 @@ class Slice(np.lib.mixins.NDArrayOperatorsMixin):
         """
         return list(self._subslices.keys())
 
-    @property
-    def coordinates(self) -> Dict[Literal['x', 'y', 'z'], np.ndarray]:
+    def get_coordinates(self, ignore_self_centered: bool = False) -> Dict[Literal['x', 'y', 'z'], np.ndarray]:
         """Returns a dictionary containing a numpy ndarray with coordinates for each dimension.
             For cell-centered slices, the coordinates are adjusted to represent cell-centered coordinates.
+
+            :param ignore_self_centered: Whether to shift the coordinates when the slice is cell_centered or not.
         """
+        orientation = ('x', 'y', 'z')[self.orientation-1] if self.orientation != 0 else ''
         coords = {'x': set(), 'y': set(), 'z': set()}
         for dim in ('x', 'y', 'z'):
+            if orientation == dim:
+                coords[dim] = np.array([self.extent[dim][0]])
+                continue
             for mesh, slc in self._subslices.items():
                 co = mesh.coordinates[dim].copy()
                 # In case the slice is cell-centered, we will shift the coordinates by half a cell
                 # and remove the last coordinate
-                if self.cell_centered:
+                if self.cell_centered and not ignore_self_centered:
                     co = co[:-1]
                     co += abs(co[1] - co[0]) / 2
                 co = co[np.where(np.logical_and(co >= slc.extent[dim][0], co <= slc.extent[dim][1]))]
@@ -391,22 +403,17 @@ class Slice(np.lib.mixins.NDArrayOperatorsMixin):
         for mesh in to_remove:
             del new_slice._subslices[mesh]
 
-        vals = new_slice._subslices.values()
-        new_slice.extent = Extent(min(vals, key=lambda e: e.extent.x_start).extent.x_start,
-                                  max(vals, key=lambda e: e.extent.x_end).extent.x_end,
-                                  min(vals, key=lambda e: e.extent.y_start).extent.y_start,
-                                  max(vals, key=lambda e: e.extent.y_end).extent.y_end,
-                                  min(vals, key=lambda e: e.extent.z_start).extent.z_start,
-                                  max(vals, key=lambda e: e.extent.z_end).extent.z_end)
-
-        if new_slice.extent.x_start == new_slice.extent.x_end:
-            new_slice.orientation = 1
-        elif new_slice.extent.y_start == new_slice.extent.y_end:
-            new_slice.orientation = 2
-        elif new_slice.extent.z_start == new_slice.extent.z_end:
-            new_slice.orientation = 3
-        else:
-            new_slice.orientation = 0
+        new_slice.orientation = slice_dim
+        subslices = new_slice._subslices.values()
+        x_start, x_end, y_start, y_end, z_start, z_end = min(subslices, key=lambda e: e.extent.x_start).extent.x_start, \
+                                                         max(subslices, key=lambda e: e.extent.x_end).extent.x_end, \
+                                                         min(subslices, key=lambda e: e.extent.y_start).extent.y_start, \
+                                                         max(subslices, key=lambda e: e.extent.y_end).extent.y_end, \
+                                                         min(subslices, key=lambda e: e.extent.z_start).extent.z_start, \
+                                                         max(subslices, key=lambda e: e.extent.z_end).extent.z_end
+        new_slice.extent = Extent(x_start, x_start if new_slice.orientation == 1 else x_end,
+                                  y_start, y_start if new_slice.orientation == 2 else y_end,
+                                  z_start, z_start if new_slice.orientation == 3 else z_end)
 
         return new_slice
 
@@ -485,7 +492,7 @@ class Slice(np.lib.mixins.NDArrayOperatorsMixin):
         """
         # The global grid will use the finest mesh as base and duplicate values of the coarser meshes
         # Therefore we first find the finest mesh and calculate the step size in each dimension
-        coords = self.coordinates
+        coords = self.get_coordinates(ignore_self_centered=True)
         step_sizes = {'x': coords['x'][-1] - coords['x'][0],
                       'y': coords['y'][-1] - coords['y'][0],
                       'z': coords['z'][-1] - coords['z'][0]}
@@ -509,18 +516,20 @@ class Slice(np.lib.mixins.NDArrayOperatorsMixin):
         start_idx = dict()
         end_idx = dict()
         for mesh, slc in self._subslices.items():
-            slc_data = slc.data
+            slc_data = slc.data if slc.orientation == 0 else np.expand_dims(slc.data, axis=slc.orientation)
             for axis in (0, 1, 2):
                 dim = ('x', 'y', 'z')[axis]
+                if axis == slc.orientation - 1:
+                    start_idx[dim] = 0
+                    end_idx[dim] = 1
+                    continue
                 n_repeat = max(int(round((mesh.coordinates[dim][1] - mesh.coordinates[dim][0]) / step_sizes[dim])), 1)
                 if self.cell_centered:
-                    start_idx[dim] = int(math.ceil((mesh.coordinates[dim][0] - start_coordinates[dim]) / step_sizes[dim]))
-                    end_idx[dim] = int(
-                        math.floor((mesh.coordinates[dim][-1] - start_coordinates[dim]) / step_sizes[dim])) + n_repeat
+                    start_idx[dim] = int(round((mesh.coordinates[dim][0] - start_coordinates[dim]) / step_sizes[dim]))
+                    end_idx[dim] = int(round((mesh.coordinates[dim][-1] - start_coordinates[dim]) / step_sizes[dim]))
                 else:
                     start_idx[dim] = int(round((mesh.coordinates[dim][0] - start_coordinates[dim]) / step_sizes[dim]))
-                    end_idx[dim] = int(
-                        round((mesh.coordinates[dim][-1] - start_coordinates[dim]) / step_sizes[dim])) + n_repeat
+                    end_idx[dim] = int(round((mesh.coordinates[dim][-1] - start_coordinates[dim]) / step_sizes[dim])) + 1
 
                 if n_repeat > 1:
                     slc_data = np.repeat(slc_data, n_repeat, axis=axis + 1)
